@@ -4,11 +4,11 @@
  * GChemPaint library
  * reaction-arrow.h
  *
- * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -75,33 +75,6 @@ Used to update the representation of the arrow in the view.
 */
 	void UpdateItem ();
 /*!
-@param Step the reaction step before the reaction
-
-Sets the initial reaction step.
-*/
-	void SetStartStep (ReactionStep *Step) {m_Start = Step;}
-/*!
-@return the initial reaction step.
-*/
-	ReactionStep* GetStartStep () {return m_Start;}
-/*!
-@param Step the reaction step after the reaction
-
-Sets the final reaction step.
-*/
-	void SetEndStep (ReactionStep *Step) {m_End = Step;}
-/*!
-@return the final reaction step.
-*/
-	ReactionStep* GetEndStep () {return m_End;}
-/*!
-@param Step the reaction step to remove from the reaction
-
-Removes the reaction step, which might be either the initial or final step.
-If it not one of these, nothing is done.
-*/
-	void RemoveStep (ReactionStep *Step);
-/*!
 @param UIManager the gcu::UIManager to populate.
 @param object the Object on which occured the mouse click.
 @param x x coordinate of the mouse click.
@@ -162,20 +135,20 @@ false otherwise.
 */
 	bool SetProperty (unsigned property, char const *value);
 
-/*!
-This method should be called when an arrow has been fully loaded.
-*/
-	void OnLoaded ();
-
 /*!
 @return the localized object generic name.
 */
 	std::string Name ();
 
+/*!
+@return a character corresponding to where the point lies relative to the arrow.
+'t' means on tail side, 'h' on head side, and 'o' for other.
+*/
+	char GetSymbolicPosition (double x, double y);
+
 private:
 	unsigned m_Type;
 	bool m_TypeChanged;
-	ReactionStep *m_Start, *m_End;
 };
 
 }	//	namespace gcp
